
dss_lib
=======


.. automodule:: opendssdirect.dss_lib
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.dss_lib.ActiveClassI

    

.. function:: opendssdirect.dss_lib.ActiveClassS

    

.. function:: opendssdirect.dss_lib.ActiveClassV

    

.. function:: opendssdirect.dss_lib.AddInAuxCurrents

    

.. function:: opendssdirect.dss_lib.BUSF

    

.. function:: opendssdirect.dss_lib.BUSI

    

.. function:: opendssdirect.dss_lib.BUSS

    

.. function:: opendssdirect.dss_lib.BUSV

    

.. function:: opendssdirect.dss_lib.BuildYMatrixD

    

.. function:: opendssdirect.dss_lib.CapControlsF

    

.. function:: opendssdirect.dss_lib.CapControlsI

    

.. function:: opendssdirect.dss_lib.CapControlsS

    

.. function:: opendssdirect.dss_lib.CapControlsV

    

.. function:: opendssdirect.dss_lib.CapacitorsF

    

.. function:: opendssdirect.dss_lib.CapacitorsI

    

.. function:: opendssdirect.dss_lib.CapacitorsS

    

.. function:: opendssdirect.dss_lib.CapacitorsV

    

.. function:: opendssdirect.dss_lib.CircuitF

    

.. function:: opendssdirect.dss_lib.CircuitI

    

.. function:: opendssdirect.dss_lib.CircuitS

    

.. function:: opendssdirect.dss_lib.CircuitV

    

.. function:: opendssdirect.dss_lib.CktElementF

    

.. function:: opendssdirect.dss_lib.CktElementI

    

.. function:: opendssdirect.dss_lib.CktElementS

    

.. function:: opendssdirect.dss_lib.CktElementV

    

.. function:: opendssdirect.dss_lib.CmathLibF

    

.. function:: opendssdirect.dss_lib.CmathLibV

    

.. function:: opendssdirect.dss_lib.DSSElementI

    

.. function:: opendssdirect.dss_lib.DSSElementS

    

.. function:: opendssdirect.dss_lib.DSSElementV

    

.. function:: opendssdirect.dss_lib.DSSExecutiveI

    

.. function:: opendssdirect.dss_lib.DSSExecutiveS

    

.. function:: opendssdirect.dss_lib.DSSI

    

.. function:: opendssdirect.dss_lib.DSSLoads

    

.. function:: opendssdirect.dss_lib.DSSLoadsF

    

.. function:: opendssdirect.dss_lib.DSSLoadsS

    

.. function:: opendssdirect.dss_lib.DSSLoadsV

    

.. function:: opendssdirect.dss_lib.DSSProperties

    

.. function:: opendssdirect.dss_lib.DSSPut_Command

    

.. function:: opendssdirect.dss_lib.DSSS

    

.. function:: opendssdirect.dss_lib.DSSV

    

.. function:: opendssdirect.dss_lib.ErrorCode

    

.. function:: opendssdirect.dss_lib.ErrorDesc

    

.. function:: opendssdirect.dss_lib.FusesF

    

.. function:: opendssdirect.dss_lib.FusesI

    

.. function:: opendssdirect.dss_lib.FusesS

    

.. function:: opendssdirect.dss_lib.FusesV

    

.. function:: opendssdirect.dss_lib.GeneratorsF

    

.. function:: opendssdirect.dss_lib.GeneratorsI

    

.. function:: opendssdirect.dss_lib.GeneratorsS

    

.. function:: opendssdirect.dss_lib.GeneratorsV

    

.. function:: opendssdirect.dss_lib.GetCompressedYMatrix

    

.. function:: opendssdirect.dss_lib.GetPCInjCurr

    

.. function:: opendssdirect.dss_lib.GetSourceInjCurrents

    

.. function:: opendssdirect.dss_lib.InitAndGetYparams

    

.. function:: opendssdirect.dss_lib.IsourceF

    

.. function:: opendssdirect.dss_lib.IsourceI

    

.. function:: opendssdirect.dss_lib.IsourceS

    

.. function:: opendssdirect.dss_lib.IsourceV

    

.. function:: opendssdirect.dss_lib.LinesF

    

.. function:: opendssdirect.dss_lib.LinesI

    

.. function:: opendssdirect.dss_lib.LinesS

    

.. function:: opendssdirect.dss_lib.LinesV

    

.. function:: opendssdirect.dss_lib.LoadShapeF

    

.. function:: opendssdirect.dss_lib.LoadShapeI

    

.. function:: opendssdirect.dss_lib.LoadShapeS

    

.. function:: opendssdirect.dss_lib.LoadShapeV

    

.. function:: opendssdirect.dss_lib.MetersF

    

.. function:: opendssdirect.dss_lib.MetersI

    

.. function:: opendssdirect.dss_lib.MetersS

    

.. function:: opendssdirect.dss_lib.MetersV

    

.. function:: opendssdirect.dss_lib.MonitorsI

    

.. function:: opendssdirect.dss_lib.MonitorsS

    

.. function:: opendssdirect.dss_lib.MonitorsV

    

.. function:: opendssdirect.dss_lib.PDElementsF

    

.. function:: opendssdirect.dss_lib.PDElementsI

    

.. function:: opendssdirect.dss_lib.PDElementsS

    

.. function:: opendssdirect.dss_lib.PVsystemsF

    

.. function:: opendssdirect.dss_lib.PVsystemsI

    

.. function:: opendssdirect.dss_lib.PVsystemsS

    

.. function:: opendssdirect.dss_lib.PVsystemsV

    

.. function:: opendssdirect.dss_lib.ParserF

    

.. function:: opendssdirect.dss_lib.ParserI

    

.. function:: opendssdirect.dss_lib.ParserS

    

.. function:: opendssdirect.dss_lib.ParserV

    

.. function:: opendssdirect.dss_lib.ReclosersF

    

.. function:: opendssdirect.dss_lib.ReclosersI

    

.. function:: opendssdirect.dss_lib.ReclosersS

    

.. function:: opendssdirect.dss_lib.ReclosersV

    

.. function:: opendssdirect.dss_lib.RegControlsF

    

.. function:: opendssdirect.dss_lib.RegControlsI

    

.. function:: opendssdirect.dss_lib.RegControlsS

    

.. function:: opendssdirect.dss_lib.RegControlsV

    

.. function:: opendssdirect.dss_lib.RelaysI

    

.. function:: opendssdirect.dss_lib.RelaysS

    

.. function:: opendssdirect.dss_lib.RelaysV

    

.. function:: opendssdirect.dss_lib.SensorsF

    

.. function:: opendssdirect.dss_lib.SensorsI

    

.. function:: opendssdirect.dss_lib.SensorsS

    

.. function:: opendssdirect.dss_lib.SensorsV

    

.. function:: opendssdirect.dss_lib.SettingsF

    

.. function:: opendssdirect.dss_lib.SettingsI

    

.. function:: opendssdirect.dss_lib.SettingsS

    

.. function:: opendssdirect.dss_lib.SettingsV

    

.. function:: opendssdirect.dss_lib.SolutionF

    

.. function:: opendssdirect.dss_lib.SolutionI

    

.. function:: opendssdirect.dss_lib.SolutionS

    

.. function:: opendssdirect.dss_lib.SolutionV

    

.. function:: opendssdirect.dss_lib.SolveSystem

    

.. function:: opendssdirect.dss_lib.SwtControlsF

    

.. function:: opendssdirect.dss_lib.SwtControlsI

    

.. function:: opendssdirect.dss_lib.SwtControlsS

    

.. function:: opendssdirect.dss_lib.SwtControlsV

    

.. function:: opendssdirect.dss_lib.SystemYChanged

    

.. function:: opendssdirect.dss_lib.TopologyI

    

.. function:: opendssdirect.dss_lib.TopologyS

    

.. function:: opendssdirect.dss_lib.TopologyV

    

.. function:: opendssdirect.dss_lib.TransformersF

    

.. function:: opendssdirect.dss_lib.TransformersI

    

.. function:: opendssdirect.dss_lib.TransformersS

    

.. function:: opendssdirect.dss_lib.TransformersV

    

.. function:: opendssdirect.dss_lib.UseAuxCurrents

    

.. function:: opendssdirect.dss_lib.VsourcesF

    

.. function:: opendssdirect.dss_lib.VsourcesI

    

.. function:: opendssdirect.dss_lib.VsourcesS

    

.. function:: opendssdirect.dss_lib.VsourcesV

    

.. function:: opendssdirect.dss_lib.XYCurvesF

    

.. function:: opendssdirect.dss_lib.XYCurvesI

    

.. function:: opendssdirect.dss_lib.XYCurvesS

    

.. function:: opendssdirect.dss_lib.XYCurvesV

    

.. function:: opendssdirect.dss_lib.ZeroInjCurr

    

.. function:: opendssdirect.dss_lib.getIpointer

    

.. function:: opendssdirect.dss_lib.getVpointer

    

